@@ -44,7 +44,7 @@ import javax.swing.JDialog;
  * DOCUMENT ME!
  *
  * @author $author$
- * @version $Revision: 1602 $
+ * @version $Revision$
  */
 public class FavouriteEditorDialog extends FGDialog
 {
@@ -171,7 +171,7 @@ public class FavouriteEditorDialog extends FGDialog
                        .getLocalizedMessage( "regular_expression" ) );
         cmbChannel.addItem( StringHelper.EMPTY_STRING );
 
-        Iterator it = allChannelsSet.getChannels(  ).iterator(  );
+        Iterator it = allChannelsSet.getSortedChannels(  ).iterator(  );
 
         while( it.hasNext(  ) )
         {
