@@ -4,7 +4,6 @@ import freeguide.common.lib.general.StringHelper;
 
 import java.io.Serializable;
 
-import java.util.Set;
 import java.util.TreeSet;
 
 /**
@@ -34,7 +33,7 @@ public class TVChannel implements Serializable
     protected String iconURL;
 
     /** List of programmes for channel. */
-    protected Set<TVProgramme> programmes = new TreeSet<TVProgramme>(  );
+    protected TreeSet<TVProgramme> programmes = new TreeSet<TVProgramme>();
 
 /**
      * Create channel with specified ID. It should be locale-insensitive.
@@ -171,7 +170,12 @@ public class TVChannel implements Serializable
     {
         programme.setChannel( this );
 
-        programmes.remove( programme );
+        // Keep on removing programmes that overlap this one until there
+        // aren't any more (note this TreeSet uses a
+        // TVProgrammeOverlapIsEqualComparator
+        while( programmes.remove( programme ) ) {}
+
+        // Now add this one
         programmes.add( programme );
     }
 
@@ -193,7 +197,7 @@ public class TVChannel implements Serializable
      *
      * @return Iterator
      */
-    public Set<TVProgramme> getProgrammes(  )
+    public TreeSet<TVProgramme> getProgrammes(  )
     {
         return programmes;
     }
