@@ -5,8 +5,10 @@ import java.util.Locale;
 import java.util.TimeZone;
 import java.util.logging.Logger;
 
+import javax.swing.JButton;
 import javax.swing.JFrame;
 import javax.swing.JMenu;
+import javax.swing.JProgressBar;
 
 /**
  * Interface for retrieve information about main application.
@@ -32,6 +34,7 @@ public interface IApplication
     void doPrint(  );
 
     Logger getLogger(  );
+    FGLogger getFGLogger(  );
 
     TimeZone getTimeZone(  );
 
@@ -59,10 +62,16 @@ public interface IApplication
      * DOCUMENT ME!
      *
      * @author $author$
-     * @version $Revision: 1600 $
+     * @version $Revision$
      */
     public interface IMainMenu
     {
         JMenu getTools(  );
     }
+    
+    IExecutionController getExecutionController();
+
+    JProgressBar getApplicationProgressBar();
+
+    JButton getApplicationForegroundButton();
 }
