@@ -1,26 +1,16 @@
 package freeguide.common.plugininterfaces;
 
-import java.util.Locale;
+import java.util.ResourceBundle;
 
 import javax.swing.JDialog;
 
 /**
  * Basic interface for all modules for freeguide-tv.
- *
+ * 
  * @author Alex Buloichik (mailto: alex73 at zaval.org)
  */
 public interface IModule
 {
-    /**
-     * Get supported locales list. This method called BEFORE
-     * setLocale. Each module MUST support "en" locale.
-     *
-     * @return List of supported locales
-     *
-     * @throws Exception
-     */
-    Locale[] getSuppotedLocales(  ) throws Exception;
-
     /**
      * Used to find the filename of the file in resources/i18n that
      * contains translations for this plugin.
@@ -33,11 +23,16 @@ public interface IModule
     /**
      * Set locale for module.
      *
-     * @param locale locale. Can be null.
-     *
      * @throws Exception
      */
-    void setLocale( Locale locale ) throws Exception;
+    void reloadResourceBundle(  ) throws Exception;
+
+    /**
+     * Get resource bundle for module.
+     *
+     * @return resource bundle
+     */
+    ResourceBundle getLocalizer(  );
 
     /**
      * Get config for store and load.
@@ -46,19 +41,12 @@ public interface IModule
      */
     Object getConfig(  );
 
-    /**
-     * DOCUMENT_ME!
-     *
-     * @return DOCUMENT_ME!
-     */
-    public ILocalizer getLocalizer(  );
-
     /**
      * Get configuration interface for support Option panel.
      *
      * @param parentDialog
      *
-     * @return
+     * @return configuration
      */
     IModuleConfigurationUI getConfigurationUI( JDialog parentDialog );
 }
