@@ -204,7 +204,7 @@ public class GrabberHallmark extends BaseModule implements IModuleGrabber
      * DOCUMENT ME!
      *
      * @author $author$
-     * @version $Revision: 1622 $
+     * @version $Revision$
      */
     public static class Config
     {
@@ -217,4 +217,16 @@ public class GrabberHallmark extends BaseModule implements IModuleGrabber
         /** Number of weeks for download. */
         public int weeksNumber = 2;
     }
+
+    public boolean chooseChannels( IProgress progress, ILogger logger )
+    {
+        // No need to choose channels for this grabber
+        return false;
+    }
+    
+    public int chooseChannelsOne( String moduleName, IProgress progress, ILogger logger )
+    {
+        // No need to choose channels for this grabber
+        return -1;
+    }
 }
