@@ -16,7 +16,7 @@ import java.util.regex.Pattern;
  * DOCUMENT ME!
  *
  * @author $author$
- * @version $Revision: 1622 $
+ * @version $Revision$
  */
 public class GrabberRbc extends BaseModule implements IModuleGrabber
 {
@@ -169,7 +169,7 @@ public class GrabberRbc extends BaseModule implements IModuleGrabber
      * DOCUMENT ME!
      *
      * @author $author$
-     * @version $Revision: 1622 $
+     * @version $Revision$
      */
     public static class DataParser extends DefaultHandler
     {
@@ -188,9 +188,21 @@ public class GrabberRbc extends BaseModule implements IModuleGrabber
      * DOCUMENT ME!
      *
      * @author $author$
-     * @version $Revision: 1622 $
+     * @version $Revision$
      */
     public static class AnnParser extends DefaultHandler
     {
     }
+
+    public boolean chooseChannels( IProgress progress, ILogger logger )
+    {
+        // No need to choose channels for this grabber
+        return false;
+    }
+
+    public int chooseChannelsOne( String moduleName, IProgress progress, ILogger logger )
+    {
+        // No need to choose channels for this grabber
+        return -1;
+    }
 }
