@@ -1,5 +1,7 @@
 package freeguide.plugins.grabber.vsetv;
 
+import freeguide.common.lib.general.StringHelper;
+
 /**
  * DOCUMENT ME!
  *
@@ -7,18 +9,20 @@ package freeguide.plugins.grabber.vsetv;
  */
 public class VsetvConfig
 {
+    protected static final String PREDEFINED_CHANNEL_GROUP = "base";
+
     /** DOCUMENT ME! */
     public boolean isAuth = false;
 
     /** DOCUMENT ME! */
-    public String user = "";
+    public String user = StringHelper.EMPTY_STRING;
 
     /** DOCUMENT ME! */
-    public String pass = "";
+    public String pass = StringHelper.EMPTY_STRING;
 
     /** DOCUMENT ME! */
     public boolean isGetAll = false;
 
     /** DOCUMENT ME! */
-    public String channelGroup = "base";
+    public String channelGroup = PREDEFINED_CHANNEL_GROUP;
 }
