@@ -8,6 +8,7 @@ import freeguide.common.lib.general.Utils;
 import freeguide.common.lib.importexport.XMLTVImport;
 
 import freeguide.common.plugininterfaces.BaseModule;
+import freeguide.common.plugininterfaces.IApplication;
 import freeguide.common.plugininterfaces.ILogger;
 import freeguide.common.plugininterfaces.IModuleConfigurationUI;
 import freeguide.common.plugininterfaces.IModuleConfigureFromWizard;
@@ -15,7 +16,9 @@ import freeguide.common.plugininterfaces.IModuleGrabber;
 import freeguide.common.plugininterfaces.IProgress;
 import freeguide.common.plugininterfaces.IStoragePipe;
 
+import freeguide.plugins.grabber.xmltv.XMLTVConfig.ModuleInfo;
 import freeguide.plugins.program.freeguide.FreeGuide;
+import freeguide.plugins.program.freeguide.lib.fgspecific.ConfigCommandRunner;
 import freeguide.plugins.program.freeguide.viewer.MainFrame;
 
 import org.xml.sax.SAXException;
@@ -104,74 +107,59 @@ public class GrabberXMLTV extends BaseModule implements IModuleGrabber,
             new File( 
                 Application.getInstance(  ).getWorkingDirectory(  ), DIR_CONFIG );
 
-        //na_dd is the only module currently
-        XMLTVConfig.ModuleInfo moduleInfo =
-            (XMLTVConfig.ModuleInfo)config.modules.get( 0 );
-
-        String cmd = moduleInfo.commandToRun;
-
-        if( null == cmd )
+        if( config.modules.size(  ) > 0 )
         {
-            cmd = getCommand( moduleInfo.moduleName, RUN_KEY_SUFFIX );
-
+            //na_dd is the only module currently
+            XMLTVConfig.ModuleInfo moduleInfo =
+                (XMLTVConfig.ModuleInfo)config.modules.get( 0 );
+    
+            String cmd = moduleInfo.commandToRun;
+    
             if( null == cmd )
             {
-                Application.getInstance(  ).getLogger(  )
-                           .severe( 
-                    "Command not defined for " + moduleInfo.moduleName );
-
-                return;
-            }
-        }
-
-        cmd = StringHelper.replaceAll( 
-                cmd, REPLACE_CONFIG,
-                new File( xmltvConfigDir, moduleInfo.configFileName )
-                .getAbsolutePath(  ) );
-
-        cmd = StringHelper.replaceAll( 
-                cmd, REPLACE_XMLTV,
-                new File( 
-                    Application.getInstance(  ).getWorkingDirectory(  ),
-                    DIR_INSTALLED ).getAbsolutePath(  ) );
-
-        if( checkXmltvExists( Utils.parseCommand( cmd ) ) ) //extracts xmltv from jar on Windows if needed
-        {
-            final JMenuItem menuLine =
-                ( (MainFrame)Application.getInstance(  ).getApplicationFrame(  ) )
-                .getMenuItemChooseXMLTVChannels(  );
-            menuLine.setText( i18n.getString( "Menu.Tools.ChooseChannels" ) );
-            Application.getInstance(  ).getMainMenu(  ).getTools(  )
-                       .insert( menuLine, 0 );
-
-            menuLine.addActionListener( 
-                new ActionListener(  )
+                cmd = getCommand( moduleInfo.moduleName, RUN_KEY_SUFFIX );
+    
+                if( null == cmd )
                 {
-                    public void actionPerformed( ActionEvent e )
+                    Application.getInstance(  ).getLogger(  )
+                               .severe( 
+                        "Command not defined for " + moduleInfo.moduleName );
+    
+                    return;
+                }
+            }
+    
+            cmd = StringHelper.replaceAll( 
+                    cmd, REPLACE_CONFIG,
+                    new File( xmltvConfigDir, moduleInfo.configFileName )
+                    .getAbsolutePath(  ) );
+    
+            cmd = StringHelper.replaceAll( 
+                    cmd, REPLACE_XMLTV,
+                    new File( 
+                        Application.getInstance(  ).getWorkingDirectory(  ),
+                        DIR_INSTALLED ).getAbsolutePath(  ) );
+    
+            if( checkXmltvExists( Utils.parseCommand( cmd ) ) ) //extracts xmltv from jar on Windows if needed
+            {
+                final JMenuItem menuLine =
+                    ( (MainFrame)Application.getInstance(  ).getApplicationFrame(  ) )
+                    .getMenuItemChooseXMLTVChannels(  );
+                menuLine.setText( i18n.getString( "Menu.Tools.ChooseChannels" ) );
+                Application.getInstance(  ).getMainMenu(  ).getTools(  )
+                           .insert( menuLine, 0 );
+    
+                menuLine.addActionListener( 
+                    new ActionListener(  )
                     {
-                        new Thread(  )
-                            {
-                                public void run(  )
-                                {
-                                    final List modules = new ArrayList(  );
-
-                                    synchronized( config.modules )
-                                    {
-                                        modules.addAll( config.modules );
-                                    }
-
-                                    for( int i = 0; i < modules.size(  );
-                                            i++ )
-                                    {
-                                        final XMLTVConfig.ModuleInfo moduleInfo =
-                                            (XMLTVConfig.ModuleInfo)modules.get( 
-                                                i );
-                                        configureChannels( moduleInfo );
-                                    }
-                                }
-                            }.start(  );
-                    }
-                } );
+                        public void actionPerformed( ActionEvent e )
+                        {
+                            IApplication app = Application.getInstance();
+                            app.getExecutionController().activate( app, new ConfigCommandRunner(),
+                                false );
+                        }
+                    } );
+            }
         }
     }
 
@@ -231,16 +219,54 @@ public class GrabberXMLTV extends BaseModule implements IModuleGrabber,
             }
         }
 
-        return ( code == 0 ) ? true : false;
+        return ( code == 0 );
     }
 
-    protected void configureChannels( final XMLTVConfig.ModuleInfo moduleInfo )
+    public int chooseChannelsOne( String moduleName,
+        IProgress progress, ILogger logger )
     {
+        ModuleInfo moduleInfo = null;
+        Iterator it = config.modules.iterator();
+        while( it.hasNext() )
+        {
+            ModuleInfo tmpModuleInfo = (ModuleInfo)( it.next() );
+            if( tmpModuleInfo.moduleName == moduleName )
+            {
+                moduleInfo = tmpModuleInfo;
+                break;
+            }
+        }
+        
+        
+        if( moduleInfo != null )
+        {
+            return configureChannelsOne( moduleInfo, progress, logger );
+        }
+        else
+        {
+            Application.getInstance().getLogger().severe(
+                "Unable to find module '" + moduleName + "'." );
+            logger.error( "Unable to find module '" + moduleName + "'." );
+            return -1;
+        }
+    }
+    
+    protected int configureChannelsOne(
+        final XMLTVConfig.ModuleInfo moduleInfo,
+        IProgress progress, ILogger logger )
+    {
+        
         final File xmltvConfigDir =
             new File( 
                 Application.getInstance(  ).getWorkingDirectory(  ), DIR_CONFIG );
         xmltvConfigDir.mkdirs(  );
 
+        if( progress != null )
+        {
+            progress.setProgressMessage(
+                Application.getInstance(  ).getLocalizedMessage( "choosing_channels" ) );
+        }
+
         String cmd = moduleInfo.configCommandToRun;
 
         if( cmd == null )
@@ -250,13 +276,15 @@ public class GrabberXMLTV extends BaseModule implements IModuleGrabber,
 
         if( cmd == null )
         {
-            Application.getInstance(  ).getLogger(  )
-                       .severe( 
+            Application.getInstance(  ).getLogger(  ).severe( 
+                "Command not defined for " + moduleInfo.moduleName );
+            
+            logger.error( 
                 MessageFormat.format( 
                     i18n.getString( "Message.CommandNotDefined" ),
                     moduleInfo.moduleName ) );
-
-            return;
+            
+            return -1;
 
         }
 
@@ -274,9 +302,18 @@ public class GrabberXMLTV extends BaseModule implements IModuleGrabber,
         Application.getInstance(  ).getLogger(  ).finest( 
             "Run command: " + cmd );
 
-        int resultCode = execConfigCmd( Utils.parseCommand( cmd ) );
+        logger.info( 
+            MessageFormat.format( i18n.getString( "Message.Command" ), cmd ) );
+
+        int resultCode = execConfigCmd( Utils.parseCommand( cmd ), progress, logger );
         Application.getInstance(  ).getLogger(  )
                    .finest( "Result code = " + resultCode );
+
+        logger.info( 
+            MessageFormat.format( 
+                i18n.getString( "Message.ResultCode" ), resultCode ) );
+
+        return resultCode;
     }
 
     protected static synchronized Map<String, String> getCommands(  )
@@ -396,7 +433,7 @@ public class GrabberXMLTV extends BaseModule implements IModuleGrabber,
             new File( 
                 Application.getInstance(  ).getWorkingDirectory(  ), DIR_CONFIG );
 
-        progress.setProgressMessage( 
+        progress.setProgressMessage(
             Application.getInstance(  ).getLocalizedMessage( "downloading" ) );
 
         String cmd = moduleInfo.commandToRun;
@@ -612,31 +649,50 @@ public class GrabberXMLTV extends BaseModule implements IModuleGrabber,
         return false;
     }
 
-    protected int execConfigCmd( final String[] args )
+    protected int execConfigCmd( 
+        final String[] args,
+        final IProgress progress, final ILogger logger )
     {
         try
         {
-            Process pr = execCmd( args );
-
-            if( pr != null )
-            {
-                new ReadProcess( pr.getInputStream(  ), Level.FINEST ).start(  );
-                new ReadProcess( pr.getErrorStream(  ), Level.FINE ).start(  );
-
-                return pr.waitFor(  );
-            }
-            else
-            {
-                return -1;
-            }
+            pr = execCmd( args );
         }
-        catch( Exception ex )
+        catch( IOException e )
         {
-            Application.getInstance(  ).getLogger(  )
-                       .log( Level.WARNING, "Error execute xmltv grabber", ex );
-
+            e.printStackTrace();
+            logger.error( e.getMessage() );
             return -1;
         }
+
+        if( pr == null )
+        {
+            return -1;
+        }
+
+        // Get the input and output streams of this process
+        BufferedReader prErr =
+            new BufferedReader( 
+                new InputStreamReader( pr.getErrorStream(  ) ) );
+
+        final Thread threadErrors = new ReadErrors( prErr, logger );
+
+        threadErrors.start(  );
+
+        int res;
+
+        try
+        {
+            res = pr.waitFor(  );
+        }
+        catch( InterruptedException ex )
+        {
+            res = -1;
+        }
+
+        threadErrors.interrupt(  );
+        pr.destroy(  );
+
+        return res;
     }
 
     /**
@@ -662,12 +718,10 @@ public class GrabberXMLTV extends BaseModule implements IModuleGrabber,
         final String regionName, final boolean runSelectChannels )
     {
         XMLTVConfig.ModuleInfo info = new XMLTVConfig.ModuleInfo(  );
-        info.moduleName = (String)getCommands(  )
-                                      .get( 
-                REGION_PREFIX + regionName + GRABBER_SUFFIX );
-        info.configFileName = (String)getCommands(  )
-                                          .get( 
-                REGION_PREFIX + regionName + GRABBER_SUFFIX )
+        info.moduleName = (String)getCommands(  ).get(
+            REGION_PREFIX + regionName + GRABBER_SUFFIX );
+        info.configFileName = (String)getCommands(  ) .get(
+            REGION_PREFIX + regionName + GRABBER_SUFFIX )
             + SUFFIX_FILE_CONFIG;
 
         synchronized( config.modules )
@@ -678,7 +732,7 @@ public class GrabberXMLTV extends BaseModule implements IModuleGrabber,
 
         if( runSelectChannels )
         {
-            configureChannels( info );
+            configureChannelsOne( info, null, Application.getInstance().getFGLogger() );
         }
     }
 
@@ -869,18 +923,50 @@ public class GrabberXMLTV extends BaseModule implements IModuleGrabber,
                     {
                         if( ( count % 10 ) == 0 )
                         {
-                            progress.setProgressMessage( 
+                            progress.setProgressMessage(
                                 MessageFormat.format( 
                                     i18n.getString( "Message.Count" ), count ) );
+                            
+                            int percent;
+                            
+                            if( config.totalProgrammesGuess == 0 )
+                            {
+                                percent = 50;
+                            }
+                            else
+                            {
+                                percent = (int)(
+                                    ( (float)count / 
+                                        (float)config.totalProgrammesGuess )
+                                    * 95.0 );
+                                
+                                if( percent > 95 )
+                                {
+                                    percent = 95;
+                                }
+                                else if( percent < 5 )
+                                {
+                                    percent = 5;
+                                }
+                            }
+
+                            progress.setProgressValue( percent );
                         }
                     }
                 };
 
             try
             {
-                new XMLTVImport(  ).process( 
+                int totalCount = new XMLTVImport(  ).process( 
                     in, storage, callback, new XMLTVImport.Filter(  ),
                     CHANNEL_PREFIX );
+                
+                progress.setProgressValue( 100 );
+
+                if( totalCount > 50 )
+                {
+                    config.totalProgrammesGuess = totalCount;
+                }
             }
             catch( SAXException ex )
             {
@@ -926,4 +1012,31 @@ public class GrabberXMLTV extends BaseModule implements IModuleGrabber,
             }
         }
     }
+
+    public boolean chooseChannels( IProgress progress, ILogger logger )
+    {
+        int code = 0;
+
+        synchronized( config.modules )
+        {
+            for( int i = 0; i < config.modules.size(  ); i++ )
+            {
+                if( Thread.interrupted(  ) )
+                {
+                    return true;
+                }
+
+                XMLTVConfig.ModuleInfo moduleInfo =
+                    (XMLTVConfig.ModuleInfo)config.modules.get( i );
+                code = configureChannelsOne( moduleInfo, progress, logger );
+
+                if( code != 0 )
+                {
+                    break;
+                }
+            }
+        }
+
+        return ( code == 0 );
+    }
 }
