@@ -1,8 +1,8 @@
 package freeguide.plugins.grabber.xmltv;
 
-import freeguide.common.lib.fgspecific.Application;
-import freeguide.common.lib.general.StringHelper;
 
+import freeguide.common.lib.fgspecific.Application;
+import freeguide.common.plugininterfaces.IApplication;
 import freeguide.common.plugininterfaces.IModuleConfigurationUI;
 
 import java.awt.Color;
@@ -292,17 +292,10 @@ public class XMLTVConfigureUIController implements IModuleConfigurationUI
          */
         public void actionPerformed( final ActionEvent e )
         {
-            new Thread(  )
-                {
-                    public void run(  )
-                    {
-                        JButton btn = (JButton)e.getSource(  );
-
-                        parent.configureChannels( moduleInfo );
-
-                    }
-                }.start(  );
-
+            IApplication app = Application.getInstance();
+            app.getExecutionController().activate( app,
+                new SingleConfigCommandRunner( parent, moduleInfo.moduleName ),
+                true );
         }
     }
 
