@@ -225,6 +225,16 @@ public class FreeGuide
                 log.log( Level.SEVERE, "Error load config", ex );
             }
 
+            if( arguments.containsKey( "working_directory" ) )
+            {
+                config.workingDirectory = arguments.getProperty( "working_directory" );
+            }
+            else
+            {
+                runtimeInfo.installDirectory = null;
+
+            }
+
             PluginsManager.loadModules(  );
 
             if( PluginsManager.getApplicationModuleInfo(  ) == null )
@@ -500,7 +510,7 @@ public class FreeGuide
      * Class for store main application config information.
      *
      * @author $author$
-     * @version $Revision: 1602 $
+     * @version $Revision$
      */
     public static class Config
     {
@@ -561,7 +571,7 @@ public class FreeGuide
      * Class for store runtime information.
      *
      * @author $author$
-     * @version $Revision: 1602 $
+     * @version $Revision$
      */
     public static class RuntimeInfo
     {
