@@ -35,7 +35,7 @@ import javax.swing.DefaultListModel;
  * DOCUMENT ME!
  *
  * @author $author$
- * @version $Revision: 1432 $
+ * @version $Revision$
  */
 public class ChannelSetEditorDialog extends FGDialog
 {
@@ -100,7 +100,7 @@ public class ChannelSetEditorDialog extends FGDialog
             csetModel.addElement( it.next(  ) );
         }
 
-        it = allChannels.getChannels(  ).iterator(  );
+        it = allChannels.getSortedChannels(  ).iterator(  );
 
         while( it.hasNext(  ) )
         {
