@@ -34,16 +34,6 @@ public class MigrateOldTo0_10_1 extends MigrationProcessBase
     protected static String xmltvConfig;
     protected static Map icons;
 
-/**
-     * Creates a new MigrateOldTo0_10_1 object.
-     *
-     * @param source DOCUMENT ME!
-     */
-    public MigrateOldTo0_10_1( final Map source )
-    {
-        super( source );
-    }
-
 /**
      * Creates a new MigrateOldTo0_10_1 object.
      *
