@@ -6,7 +6,9 @@ import freeguide.common.lib.fgspecific.data.TVData;
 import freeguide.common.lib.general.Utils;
 
 import freeguide.common.plugininterfaces.BaseModule;
+import freeguide.common.plugininterfaces.FGLogger;
 import freeguide.common.plugininterfaces.IApplication;
+import freeguide.common.plugininterfaces.IExecutionController;
 import freeguide.common.plugininterfaces.IModuleExport;
 import freeguide.common.plugininterfaces.IModuleGrabber;
 import freeguide.common.plugininterfaces.IModuleImport;
@@ -16,7 +18,8 @@ import freeguide.common.plugininterfaces.IModuleViewer;
 
 import freeguide.plugins.program.freeguide.FreeGuide;
 import freeguide.plugins.program.freeguide.dialogs.ChannelSetListDialog;
-import freeguide.plugins.program.freeguide.lib.fgspecific.GrabberController;
+import freeguide.plugins.program.freeguide.lib.fgspecific.ExecutionController;
+import freeguide.plugins.program.freeguide.lib.fgspecific.GrabberCommandRunner;
 import freeguide.plugins.program.freeguide.lib.fgspecific.PluginInfo;
 import freeguide.plugins.program.freeguide.lib.fgspecific.PluginsManager;
 import freeguide.plugins.program.freeguide.lib.fgspecific.StoragePipe;
@@ -29,8 +32,6 @@ import java.awt.Rectangle;
 import java.awt.Toolkit;
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
-import java.awt.event.MouseEvent;
-import java.awt.event.MouseListener;
 
 import java.text.MessageFormat;
 
@@ -44,7 +45,9 @@ import java.util.TreeSet;
 import java.util.logging.Level;
 import java.util.logging.Logger;
 
+import javax.swing.JButton;
 import javax.swing.JFrame;
+import javax.swing.JProgressBar;
 import javax.swing.LookAndFeel;
 import javax.swing.SwingUtilities;
 import javax.swing.UIManager;
@@ -64,7 +67,7 @@ public class MainController extends BaseModule implements IApplication
 
     /** DOCUMENT ME! */
     public IModuleViewer viewer;
-    protected GrabberController grab = new GrabberController(  );
+    protected ExecutionController executionController = new ExecutionController(  );
     protected IModuleReminder[] reminders;
     protected JFrame applicationFrame;
 
@@ -274,35 +277,6 @@ public class MainController extends BaseModule implements IApplication
         this.viewer.getPanel(  ).updateUI(  );
     }
 
-    /**
-     * Checks whether the XMLTVLoader managed to get any data, and
-     * asks the user to download more if not.
-     */
-
-    /*protected void checkForNoData(  )
-    {
-        if(
-            !Application.getInstance(  ).getDataStorage(  ).getInfo(  ).channelsList
-                .isEmpty(  ) )
-        {
-            return;
-        }
-
-        int r =
-            JOptionPane.showConfirmDialog(
-                Application.getInstance(  ).getApplicationFrame(  ),
-                Application.getInstance(  )
-                           .getLocalizedMessage(
-                    "there_are_missing_listings_for_today" ),
-                Application.getInstance(  )
-                           .getLocalizedMessage( "download_listings_q" ),
-                JOptionPane.YES_NO_OPTION );
-
-        if( r == 0 )
-        {
-            Application.getInstance(  ).doStartGrabbers(  );
-        }
-    }*/
     /**
      * Starts up all grabbers and reminders via their start() method.
      */
@@ -469,7 +443,8 @@ public class MainController extends BaseModule implements IApplication
      */
     public void doStartGrabbers(  )
     {
-        grab.activate( this );
+        executionController.activate( this, new GrabberCommandRunner(),
+            true );
     }
 
     /**
@@ -479,7 +454,8 @@ public class MainController extends BaseModule implements IApplication
      */
     public void doShowGrabbers(  )
     {
-        grab.activate( this );
+        executionController.activate( this, new GrabberCommandRunner(),
+            true );
     }
 
     /**
@@ -635,17 +611,16 @@ public class MainController extends BaseModule implements IApplication
         return FreeGuide.runtimeInfo.installDirectory;
     }
 
-    /**
-     * DOCUMENT_ME!
-     *
-     * @return DOCUMENT_ME!
-     */
-    public Logger getLogger(  )
+    public Logger getLogger()
     {
-        // TODO Auto-generated method stub
         return FreeGuide.log;
     }
 
+    public FGLogger getFGLogger(  )
+    {
+        return new FGLogger( FreeGuide.log );
+    }
+
     /**
      * DOCUMENT_ME!
      *
@@ -653,7 +628,6 @@ public class MainController extends BaseModule implements IApplication
      */
     public String getWorkingDirectory(  )
     {
-        // TODO Auto-generated method stub
         return FreeGuide.config.workingDirectory;
     }
 
@@ -693,7 +667,7 @@ public class MainController extends BaseModule implements IApplication
      * DOCUMENT ME!
      *
      * @author $author$
-     * @version $Revision: 1649 $
+     * @version $Revision$
      */
     public static class Config
     {
@@ -719,7 +693,7 @@ public class MainController extends BaseModule implements IApplication
          * DOCUMENT ME!
          *
          * @author $author$
-         * @version $Revision: 1649 $
+         * @version $Revision$
          */
         public static class UI
         {
@@ -745,4 +719,19 @@ public class MainController extends BaseModule implements IApplication
             }
         }
     }
+
+    public IExecutionController getExecutionController()
+    {
+        return executionController;
+    }
+
+    public JButton getApplicationForegroundButton()
+    {
+        return mainFrame.getForegroundButton();
+    }
+
+    public JProgressBar getApplicationProgressBar()
+    {
+        return mainFrame.getProgressBar();
+    }
 }
